import { RateLimiter } from "discord.js-rate-limiter";
import { Client, Message } from "discord.js-light";
import { Category, CommandObj, CommandOptions, CustomizablePrefix, ModifiedClient } from "../types";
import Plugin from "./Plugin";
export default class {
    client: ModifiedClient;
    prefixOnMention: boolean;
    prefix: string;
    customizablePrefix: CustomizablePrefix | null;
    rateLimiter: RateLimiter | null;
    categories: Category[];
    commands: CommandObj[];
    private _plugins;
    /**
     * @param {Client} client The default discord.js client
     * @param {string} path The path relative to the root of the project
     * @param {
     * 	{
     * 		prefix: string,
     * 		prefixOnMention?: boolean,
     * 		customizablePrefix?: CustomizablePrefix,
     *  	defaultCategory?: Category,
     *  	help?: HelpOptions,
     *  	rateLimiter?: RateLimiterOptions
     * 	}
     * }options Creation options
     */
    constructor(client: Client, path: string, options: CommandOptions);
    /**
     * Adds another category to the list
     *
     * @param {string} name The name that will be referenced in commands
     * @param {string} title The title to display in the help message
     */
    addCategory(name: string, title: string): this;
    /**
     * Registers a plugin
     *
     * @param {Plugin} plugin The plugin to register
     * @return {Commands}
     */
    addPlugin(plugin: Plugin): this;
    /**
     * Get an array of all active plugins
     */
    get plugins(): string[];
    messageEvent(message: Message): Promise<Message | undefined>;
}
